FlutterIntroScreen class

Inheritance

Constructors

FlutterIntroScreen({Key? key, required Widget centerWidget, required List<IntroPageData> pageData, required VoidCallback onCompletePressed, IntroMessages messages = const IntroMessages(), IntroInsets insets = const IntroInsets(), IntroDurations durations = const IntroDurations(), IntroColors colors = const IntroColors(), IntroText texts = const IntroText()})
const

Properties

final
centerWidget → Widget
final
colors → IntroColors
final
durations → IntroDurations
final
hashCode → int
The hash code for this object.
no setterinherited
insets → IntroInsets
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
messages → IntroMessages
final
onCompletePressed → VoidCallback
final
pageData → List<IntroPageData>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texts → IntroText
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<FlutterIntroScreen>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited