IntroDurations class

Constructors

IntroDurations({Duration fast = const Duration(milliseconds: 300), Duration med = const Duration(milliseconds: 600), Duration slow = const Duration(milliseconds: 900), Duration pageTransition = const Duration(milliseconds: 200)})
const

Properties

fast → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
med → Duration
final
pageTransition → Duration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
slow → Duration
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited