IntroInsets class

Constructors

IntroInsets({double xxs = 4, double xs = 8, double sm = 16, double md = 24, double lg = 32, double xl = 48, double xxl = 56})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
lg → double
final
md → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sm → double
final
xl → double
final
xs → double
final
xxl → double
final
xxs → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited