IntroMessages class

Constructors

IntroMessages({String swap = "Swap left to continue", String navigate = "Navigate"})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
swap → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited