IntroPageData class

Annotations

Constructors

IntroPageData({required Widget title, required Widget description, required Widget image, Widget? mask})
const

Properties

description → Widget
final
hashCode → int
The hash code for this object.
no setterinherited
image → Widget
final
mask → Widget?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → Widget
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited